<?php

namespace Drupal\mocean_sms_order_notification\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\state_machine\Event\WorkflowTransitionEvent;
use Drupal\mocean_sms_order_notification\Utility;

class SendShipmentSubscriber implements EventSubscriberInterface {

  public static function getSubscribedEvents() {
    $events = ['commerce_shipment.ship.post_transition' => 'onSend'];
	return $events;
  }

  public function onSend(WorkflowTransitionEvent $event) {
	$sms_order_notification_content = \Drupal::config('mocean_sms_order_notification.content');
	$enable = $sms_order_notification_content->get('shipped_enable');
	$order = $event->getEntity();
	$database = \Drupal::database();
	$query = $database->query('SELECT uid FROM commerce_order WHERE order_id = :order_id LIMIT 1', [':order_id' => $order->getOrderId(),]);
    $result = $query->fetchField();
	$recipient = (new Utility)->getPhone($result);
	
	if ($recipient && $enable) {
	  $message = str_replace('{order_number}', $order->getOrderId(), $sms_order_notification_content->get('shipped_content'));
	  $message = str_replace('{tracking_code}', $order->getTrackingCode(), $message);
	
	  $jsonResponse = (new Utility)->smsOrderNotificationSendMessage($recipient, $message);
	  
	  if (count($jsonResponse) == count($jsonResponse, COUNT_RECURSIVE)) {
	  $status = $jsonResponse['status'];
	  $is_arr = FALSE;
	}
	else {
	  $status = $jsonResponse['messages'][0]['status'];
	  $is_arr = TRUE;
	}
	
	if ($status != 0)
	  if ($is_arr)
	    \Drupal::messenger()->addError('Notification SMS could not be sent. '.$jsonResponse['messages'][0]['err_msg']);
	  else
		\Drupal::messenger()->addError('Notification SMS could not be sent. '.$jsonResponse['err_msg']);
    }
	
  }
}