<?php

namespace Drupal\mocean_sms_order_notification\Plugin\Commerce\CheckoutPane;

use Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneBase;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneInterface;
use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\mocean_sms_order_notification\Utility;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a completion SMS pane.
 *
 * @CommerceCheckoutPane(
 *   id = "checkout_pane_complete_order",
 *   label = @Translation("Completion SMS"),
 *   default_step = "_disabled",
 * )
 */
class CompletionMessagePane extends CheckoutPaneBase {
	
  
  public function defaultConfiguration() {
    return [
      'content' => 'Your order with order number {order_number} is completed.',
    ] + parent::defaultConfiguration();
  }

  public function buildConfigurationSummary() {
    return $this->t('Content: @content', ['@content' => $this->configuration['content']]);
  }

  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['content'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Content'),
      '#default_value' => $this->configuration['content'],
    ];

    return $form;
  }

  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);

    if (!$form_state->getErrors()) {
      $values = $form_state->getValue($form['#parents']);
      $this->configuration['content'] = $values['content'];
    }
  }

  public function buildPaneForm(array $pane_form, FormStateInterface $form_state, array &$complete_form) {
	$recipient = (new Utility)->getPhone($this->order->getCustomerId());
	
	if ($recipient) {
	  $message = str_replace('{order_number}', $this->order->id(), $this->configuration['content']);
	  $jsonResponse = (new Utility)->smsOrderNotificationSendMessage($recipient, $message);
	  
	  if (count($jsonResponse) == count($jsonResponse, COUNT_RECURSIVE)) {
	    $status = $jsonResponse['status'];
	    $is_arr = FALSE;
	  }
	  else {
	    $status = $jsonResponse['messages'][0]['status'];
	    $is_arr = TRUE;
	  }
	
	  if ($status != 0) {
	    if ($is_arr)
	      \Drupal::messenger()->addError('Notification SMS could not be sent. '.$jsonResponse['messages'][0]['err_msg']);
	    else
	  	  \Drupal::messenger()->addError('Notification SMS could not be sent. '.$jsonResponse['err_msg']);
      }
	  
	  return $pane_form;
    }
  }
}